@@ -61,7 +61,7 @@ impl Generator for Spec {
 
     fn generate(&self, cmd: &clap::Command, buf: &mut dyn std::io::Write) {
         let command = command_for(cmd, true);
-        let serialized = serde_yaml::to_string(&command).unwrap();
+        let serialized = serde_yaml_ng::to_string(&command).unwrap();
         buf.write_all(serialized.as_bytes())
             .expect("Failed to write to generated file");
     }
@@ -238,11 +238,11 @@ fn action_for<'a>(hint: ValueHint) -> Vec<String> {
         FilePath => vec!["$files"],
         DirPath => vec!["$directories"],
         ExecutablePath => vec!["$files"],
-        CommandName => vec!["$_os.PathExecutables", "$files"],
-        CommandString => vec!["$_os.PathExecutables", "$files"],
+        CommandName => vec!["$executables", "$files"],
+        CommandString => vec!["$executables", "$files"],
         CommandWithArguments => vec!["TODO"], // TODO
-        Username => vec!["$_os.Users"],
-        Hostname => vec!["$_net.Hosts"],
+        Username => vec!["$carapace.os.Users"],
+        Hostname => vec!["$carapace.net.Hosts"],
         Url => vec![],
         EmailAddress => vec![],
         _ => vec![],
